==> cds-services-impl-1.18.0-sources.jar: com/sap/cds/services/impl/messaging/composite/MessagingCompositeService.java <==
/**************************************************************************
 * (C) 2019-2021 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.impl.messaging.composite;

import java.util.List;
import java.util.Map;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.sap.cds.services.ErrorStatuses;
import com.sap.cds.services.environment.CdsProperties.Composite.CompositeServiceConfig;
import com.sap.cds.services.environment.CdsProperties.Composite.CompositeServiceConfig.Route;
import com.sap.cds.services.impl.composite.CompositeService;
import com.sap.cds.services.messaging.MessagingService;
import com.sap.cds.services.messaging.TopicMessageEventContext;
import com.sap.cds.services.runtime.CdsRuntime;
import com.sap.cds.services.utils.ErrorStatusException;

public class MessagingCompositeService extends CompositeService implements MessagingService {

	private static final ObjectMapper mapper = new ObjectMapper();

	public MessagingCompositeService(String name, List<Route> routes, CdsRuntime runtime) {
		super(toCompositeConfig(name, routes), runtime);
	}

	@Override
	public void emit(String topic, String message) {
		TopicMessageEventContext context = TopicMessageEventContext.create(topic);
		context.setData(message);

		emit(context);
	}

	@Override
	public void emit(String topic, Map<String, Object> message) {
		emit(topic, toJson(message));
	}

	private String toJson(Object object) {
		try {
			return mapper.writeValueAsString(object);
		} catch (JsonProcessingException e) {
			throw new ErrorStatusException(ErrorStatuses.SERVER_ERROR, e);
		}
	}

	private static CompositeServiceConfig toCompositeConfig(String name, List<Route> routes) {
		CompositeServiceConfig result = new CompositeServiceConfig();
		result.setName(name);
		result.setRoutes(routes);
		return result;
	}
}

==> cds-services-impl-1.32.1-sources.jar: com/sap/cds/services/impl/messaging/composite/MessagingCompositeService.java <==
/**************************************************************************
 * (C) 2019-2021 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.impl.messaging.composite;

import java.util.List;
import java.util.Map;

import com.sap.cds.services.environment.CdsProperties.Composite.CompositeServiceConfig;
import com.sap.cds.services.environment.CdsProperties.Composite.CompositeServiceConfig.Route;
import com.sap.cds.services.impl.composite.CompositeService;
import com.sap.cds.services.messaging.MessagingService;
import com.sap.cds.services.messaging.TopicMessageEventContext;
import com.sap.cds.services.runtime.CdsRuntime;
import com.sap.cds.services.utils.messaging.CloudEventUtils;

public class MessagingCompositeService extends CompositeService implements MessagingService {

	public MessagingCompositeService(String name, List<Route> routes, CdsRuntime runtime) {
		super(toCompositeConfig(name, routes), runtime);
	}

	@Override
	public void emit(String topic, String message) {
		TopicMessageEventContext context = TopicMessageEventContext.create(topic);
		context.setData(message);

		emit(context);
	}

	@Override
	public void emit(String topic, Map<String, Object> message) {
		emit(topic, CloudEventUtils.toJson(message));
	}

	private static CompositeServiceConfig toCompositeConfig(String name, List<Route> routes) {
		CompositeServiceConfig result = new CompositeServiceConfig();
		result.setName(name);
		result.setRoutes(routes);
		return result;
	}
}
